@@ -2,7 +2,7 @@ from django.conf import settings
 
 
 PIPELINE = getattr(settings, 'PIPELINE', not settings.DEBUG)
-PIPELINE_ROOT = getattr(settings, 'PIPELINE_ROOT', settings.STATIC_URL)
+PIPELINE_ROOT = getattr(settings, 'PIPELINE_ROOT', settings.STATIC_ROOT)
 PIPELINE_URL = getattr(settings, 'PIPELINE_URL', settings.STATIC_URL)
 
 PIPELINE_STORAGE = getattr(settings, 'PIPELINE_STORAGE',
