@@ -1,7 +1,9 @@
 import os
 import sys
+import urllib
 
 from django.utils import importlib
+from django.utils.encoding import smart_str
 
 
 def to_class(class_str):
@@ -14,6 +16,12 @@ def to_class(class_str):
     return getattr(module, class_name, None)
 
 
+def filepath_to_uri(path):
+    if path is None:
+        return path
+    return urllib.quote(smart_str(path).replace("\\", "/"), safe="/~!*()'#?")
+
+
 def _relpath_nt(path, start=os.path.curdir):
     """Return a relative version of a path"""
     if not path:
