@@ -1,4 +1,5 @@
+# -*- coding: utf-8 flake8: noqa -*-
 from packager import *
-from versioning import *
 from compressor import *
 from compiler import *
+from storage import *
